# New Prod Config 

## zen40az180_dl1ab_tuned_psf

## Short description of the config

Modified standard config to tune the PSF and to run the process for zenith 40 deg, south pointing MC

## Why this config is needed 

For aiding in the source-independent analysis of sources like the AGNs where the NSB is weak and therefore not requiring any change.
